/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package android.telephony.mbms;

import android.content.Context;
import java.util.concurrent.Executor;
import android.telephony.MbmsStreamingSession;

/**
 * A callback class that is used to receive information from the middleware on MBMS streaming
 * services. An instance of this object should be passed into
 * {@link MbmsStreamingSession#create(Context, Executor, int, MbmsStreamingSessionCallback)}.
 * @apiSince 28
 */

@SuppressWarnings({"unchecked", "deprecation", "all"})
public class MbmsStreamingSessionCallback {

public MbmsStreamingSessionCallback() { throw new RuntimeException("Stub!"); }

/**
 * Called by the middleware when it has detected an error condition. The possible error codes
 * are listed in {@link MbmsErrors}.
 * @param errorCode The error code.
 * Value is {@link android.telephony.mbms.MbmsErrors#ERROR_NO_UNIQUE_MIDDLEWARE}, {@link android.telephony.mbms.MbmsErrors#ERROR_MIDDLEWARE_LOST}, {@link android.telephony.mbms.MbmsErrors#ERROR_MIDDLEWARE_NOT_BOUND}, {@link android.telephony.mbms.MbmsErrors.InitializationErrors#ERROR_APP_PERMISSIONS_NOT_GRANTED}, {@link android.telephony.mbms.MbmsErrors.InitializationErrors#ERROR_DUPLICATE_INITIALIZE}, {@link android.telephony.mbms.MbmsErrors.InitializationErrors#ERROR_UNABLE_TO_INITIALIZE}, {@link android.telephony.mbms.MbmsErrors.GeneralErrors#ERROR_MIDDLEWARE_NOT_YET_READY}, {@link android.telephony.mbms.MbmsErrors.GeneralErrors#ERROR_OUT_OF_MEMORY}, {@link android.telephony.mbms.MbmsErrors.GeneralErrors#ERROR_MIDDLEWARE_TEMPORARILY_UNAVAILABLE}, {@link android.telephony.mbms.MbmsErrors.GeneralErrors#ERROR_IN_E911}, {@link android.telephony.mbms.MbmsErrors.GeneralErrors#ERROR_NOT_CONNECTED_TO_HOME_CARRIER_LTE}, {@link android.telephony.mbms.MbmsErrors.GeneralErrors#ERROR_UNABLE_TO_READ_SIM}, {@link android.telephony.mbms.MbmsErrors.GeneralErrors#ERROR_CARRIER_CHANGE_NOT_ALLOWED}, {@link android.telephony.mbms.MbmsErrors.StreamingErrors#ERROR_CONCURRENT_SERVICE_LIMIT_REACHED}, {@link android.telephony.mbms.MbmsErrors.StreamingErrors#ERROR_UNABLE_TO_START_SERVICE}, or {@link android.telephony.mbms.MbmsErrors.StreamingErrors#ERROR_DUPLICATE_START_STREAM}
 * @param message A human-readable message generated by the middleware for debugging purposes.
 
 * This value may be {@code null}.
 * @apiSince 28
 */

public void onError(int errorCode, @android.annotation.Nullable java.lang.String message) { throw new RuntimeException("Stub!"); }

/**
 * Called to indicate published Streaming Services have changed.
 *
 * This will only be called after the application has requested
 * a list of streaming services and specified a service class list
 * of interest AND the results of a subsequent getStreamServices
 * call with the same service class list would return different
 * results.
 *
 * @param services The list of available services.
 * @apiSince 28
 */

public void onStreamingServicesUpdated(java.util.List<android.telephony.mbms.StreamingServiceInfo> services) { throw new RuntimeException("Stub!"); }

/**
 * Called to indicate that the middleware has been initialized and is ready.
 *
 * Before this method is called, calling any method on an instance of
 * {@link MbmsStreamingSession} will result in an {@link IllegalStateException} or an error
 * delivered via {@link #onError(int, String)} with error code
 * {@link MbmsErrors.GeneralErrors#ERROR_MIDDLEWARE_NOT_YET_READY}.
 * @apiSince 28
 */

public void onMiddlewareReady() { throw new RuntimeException("Stub!"); }
}

